arc_geo_multi: Geocoding using the ArcGIS REST API with multi-field query

View source: R/arc_geo_multi.R

arc_geo_multiR Documentation

Geocoding using the ArcGIS REST API with multi-field query

Description

Geocodes addresses given specific address components. This function returns the tibble associated with the query.

For geocoding using a single text string use arc_geo() function.

Usage

arc_geo_multi(
  address = NULL,
  address2 = NULL,
  address3 = NULL,
  neighborhood = NULL,
  city = NULL,
  subregion = NULL,
  region = NULL,
  postal = NULL,
  postalext = NULL,
  countrycode = NULL,
  lat = "lat",
  long = "lon",
  limit = 1,
  full_results = FALSE,
  return_addresses = TRUE,
  verbose = FALSE,
  progressbar = TRUE,
  outsr = NULL,
  langcode = NULL,
  category = NULL,
  custom_query = list()
)

Arguments

address, address2, address3, neighborhood, city, subregion

Address components. See Details.

region, postal, postalext, countrycode

Additional address components. See Details.

lat

Latitude column name in the output data (default "lat").

long

Longitude column name in the output data (default "lon").

limit

Maximum number of results to return per input address. Each query has a hard API limit of 50 results.

full_results

Logical; if TRUE return all available API fields via ⁠outFields=*⁠. Default is FALSE.

return_addresses

Logical; if TRUE keep input query in output.

verbose

Logical; if TRUE output process messages to console.

progressbar

Logical; if TRUE shows a progress bar for multiple points.

outsr

The spatial reference of the ⁠x,y⁠ coordinates returned by a geocode request. By default is NULL (i.e. the argument won't be used in the query). See Details and arc_spatial_references.

langcode

Sets the language in which reverse-geocoded addresses are returned.

category

Place or address type used as a filter. Multiple values are accepted (e.g. c("Cinema", "Museum")). See arc_categories.

custom_query

Additional API parameters as named list values.

Details

See the ArcGIS REST docs for more info and valid values.

Value

A tibble object with the results. See the details of the output in ArcGIS REST API Service output.

The resulting output will include also the input arguments (columns with prefix q_) for better tracking the results.

Address components

This function allows performing structured queries by different components of an address. At least one field should be different than NA or NULL.

A vector of values can be provided for each argument for multiple geocoding. When using vectors on different arguments, their lengths should be the same.

The following list provides a brief description of each argument:

  • address: A string that represents the first line of a street address. In most cases it will be the street name and house number input, but it can also be used to input building name or place-name.

  • address2: A string that represents the second line of a street address. This can include street name/house number, building name, place-name, or sub unit.

  • address3: A string that represents the third line of a street address. This can include street name/house number, building name, place-name, or sub unit.

  • neighborhood: The smallest administrative division associated with an address, typically, a neighborhood or a section of a larger populated place.

  • city: The next largest administrative division associated with an address, typically, a city or municipality.

  • subregion: The next largest administrative division associated with an address. Depending on the country, a sub region can represent a county, state, or province.

  • region: The largest administrative division associated with an address, typically, a state or province.

  • postal: The standard postal code for an address, typically, a three– to six-digit alphanumeric code.

  • postalext: A postal code extension, such as the United States Postal Service ZIP+4 code.

  • countrycode: A value representing the country. Providing this value increases geocoding speed. Acceptable values include the full country name in English or the official language of the country, the two-character country code, or the three-character country code.

outsr

The spatial reference can be specified as either a well-known ID (WKID). If not specified, the spatial reference of the output locations is the same as that of the service (WGS84, i.e. WKID = 4326)).

See arc_spatial_references for values and examples.

References

ArcGIS REST findAddressCandidates

See Also

tidygeocoder::geo()

Other functions for geocoding: arc_geo(), arc_geo_categories(), arc_reverse_geo()

Examples



simple <- arc_geo_multi(
  address = "Plaza Mayor", limit = 10,
  custom_query = list(outFields = c("LongLabel", "CntryName", "Region"))
)

library(dplyr)

simple |>
  select(lat, lon, CntryName, Region, LongLabel) |>
  slice_head(n = 10)

# Restrict search to Spain
simple2 <- arc_geo_multi(
  address = "Plaza Mayor", countrycode = "ESP",
  limit = 10,
  custom_query = list(outFields = c("LongLabel", "CntryName", "Region"))
)

simple2 |>
  select(lat, lon, CntryName, Region, LongLabel) |>
  slice_head(n = 10)

# Restrict to a region
simple3 <- arc_geo_multi(
  address = "Plaza Mayor", region = "Segovia",
  countrycode = "ESP",
  limit = 10,
  custom_query = list(outFields = c("LongLabel", "CntryName", "Region"))
)

simple3 |>
  select(lat, lon, CntryName, Region, LongLabel) |>
  slice_head(n = 10)



arcgeocoder documentation built on March 20, 2026, 5:10 p.m.