| arc_spatial_references | R Documentation |
Database of available spatial references (CRS) in tibble format.
A tibble with 9,608 rows and fields:
Projection type ("ProjectedCoordinateSystems", "GeographicCoordinateSystems","VerticalCoordinateSystems")
Well-Known ID
Most recent wkid, in case that wkid is deprecated
wkid authority (Esri or EPSG)
Logical indicating if wkid is deprecated
Human-readable description of the wkid
Use area of the wkid
Representation of wkid in Well-Known Text (WKT). Useful when
working with sf or terra
This data base is useful when using the outsr argument of the functions.
Some projections ids have changed over time, for example Web Mercator is
wkid = 102100 is deprecated and currently is wkid = 3857. However, both
values would work, and they would return similar results.
Data extracted on 15 January 2026.
ESRI Projection Engine factory
sf::st_crs()
Other datasets:
arc_categories
# Get all possible values
data("arc_spatial_references")
arc_spatial_references
# Request with deprecated Web Mercator
library(dplyr)
wkid <- arc_spatial_references |>
filter(latestWkid == 3857 & deprecated == TRUE) |>
slice(1)
glimpse(wkid)
add <- arc_geo("London, United Kingdom", outsr = wkid$wkid)
# Note values lat, lon and wkid. latestwkid give the current valid wkid
add |>
select(lat, lon, wkid, latestWkid) |>
glimpse()
# See with sf
try(sf::st_crs(wkid$wkid))
# But
try(sf::st_crs(wkid$latestWkid))
# or
try(sf::st_crs(wkid$wkt))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.